@@ -29,10 +29,9 @@ use namespace::autoclean;
 
 use Test::Routine;
 with 'Test::Dist::Zilla::Build';
+with 'Test::Dist::Zilla::BuiltFiles';
 
 use Test::More;
-use Test::Deep qw{ cmp_deeply };
-use Path::Tiny;
 
 has options => (
     isa         => 'HashRef',
@@ -57,37 +56,6 @@ sub _build_message_filter {
     };
 };
 
-test 'Files' => sub {
-    my ( $self ) = @_;
-    if ( $self->exception ) {
-        plan skip_all => 'exception occurred';
-    };
-    if ( not exists( $self->expected->{ files } ) ) {
-        plan skip_all => 'no expected files specified';
-    };
-    my @names = keys( %{ $self->expected->{ files } } );
-    my $built_in = path( $self->tzil->built_in );
-    plan 'no_plan';
-    for my $name ( @names ) {
-        my $exp = $self->expected->{ files }->{ $name };
-        my $file = $built_in->child( $name );
-        if ( defined( $exp ) ) {
-            ok( $file->exists, "$name exists" ) and do {
-                my $act = ref( $exp ) ? (
-                    [ $file->lines_utf8( { chomp => 1 } ) ]
-                ) : (
-                    $file->slurp_utf8()
-                );
-                cmp_deeply( $act, $exp, "$name content" ) or do {
-                    $self->_anno_text( $name, ref( $act ) ? @$act : $act );
-                };
-            };
-        } else {
-            ok( ! $file->exists, "$name not exist" );
-        };
-    };
-};
-
 1;
 
 # end of file #
